### Name: plot
### Title: Plot method for fitted IRT models
### Aliases: plot.grm plot.ltm plot.rasch
### Keywords: methods

### ** Examples


# Examples for plot.grm()

m <- grm(Science[c(1,3,4,7)])

## Item Response Category Characteristic Curves for 
## the Science data
op <- par(mfrow = c(2, 2))
plot(m, lwd = 2, legend = TRUE, ncol = 2)
# re-set par()
par(op)

## Item Characteristic Curves for the 2nd category,
## and items 1 and 3
plot(m, category = 2, items = c(1, 3), lwd = 2, legend = TRUE, cx = "right")

## Item Information Curves for the Science data;
plot(m, type = "IIC",  legend = TRUE, cx = "topright", lwd = 2, cex = 1.4)

## Test Information Function for the Science data;
plot(m, type = "IIC",  items = 0, lwd = 2)

###################################################

# Examples for plot.ltm()

## Item Characteristic Curves for the two-parameter logistic
## model; plot only items 1, 2, 4 and 6:
m <- ltm(Wirs ~ z1)
plot(m, items = c(1, 2, 4, 6), lwd = 3, cex = 1.4)

## Test Information Function under the two-parameter logistic
## model for the Lsat data
m <- ltm(Lsat ~ z1)
plot(m, type = "IIC", items = 0, lwd = 2, cex.lab = 1.2, cex.main = 1.3)
info <- information(m, c(-3, 0))
text(x = 2, y = 0.5, labels = paste("Total Information:", round(info$Total, 3), 
    "\n\nInformation in (-3, 0):", round(info$Info, 3), 
    paste("(", round(100 * info$Proportion, 2), "%)", sep = "")), cex = 1.2)

## Item Characteristic Surfaces for the interaction model:
m <- ltm(Wirs ~ z1 * z2)
plot(m)

###################################################

# Examples for plot.rasch()

## Item Characteristic Curves for the Wirs data;
## plot only items 1, 3 and 5:
m <- rasch(Wirs)
plot(m, items = c(1, 3, 5), lwd = 3, cex = 1.4)

m <- rasch(Lsat)

## Item Characteristic Curves for the Lsat data;
## plot all items plus a legend; increase 'cex.lab' 
## and 'cex.main' using par()
op <- par(cex.lab = 1.6, cex.main = 2)
plot(m, legend = TRUE, cx = "right", lwd = 3, cex = 1.4)
par(op)

## Item Information Curves, for the first 3 items; include a legend
plot(m, type = "IIC", items = 1:3, legend = TRUE, lwd = 2, cx = "topright")

## Test Information Function
plot(m, type = "IIC", items = 0, lwd = 2, cex.lab = 1.1)
info <- information(m, c(-2, 0))
text(x = 2, y = 0.5, labels = paste("Total Information:", round(info$Total, 3), 
    "\n\nInformation in (-2, 0):", round(info$Info, 3), 
    paste("(", round(100 * info$Prop, 2), "%)", sep = "")), cex = 1.2)



